// pages/test/index.js
const app = getApp()
import WxValidate from '../../utils/wxValidate'
Page({

    /**
     * 页面的初始数据
     */
    data: {
        frameStyle: { useTop: true, name: '收货地址', leftArrow: true, useBar: false },
        // 主体高度
        infoHeight: '',
        form: {},
        id: '',
    },
    initValidate() {
        const rules = { user_name: { required: true }, phone: { required: true, tel: true }, self_id: { required: true }, address: { required: true } }
        // 验证字段的提示信息，若不传则调用默认的信息
        const messages = { user_name: { required: '收货人姓名', }, phone: { required: '联系电话', }, self_id: { required: '请选择自提点', }, address: { required: '详细地址' } };
        this.WxValidate = new WxValidate(rules, messages)
    },
    // 跳转菜单
    tabPath(e) {
        let { route } = e.detail.detail;
        if (route) wx.redirectTo({ url: `/${route}` })
    },
    back: function () {
        wx.navigateBack({ url: '/pages/home/index' })
    },
    // 请选择自提点
    toSelt: function () {
        const that = this;
        wx.navigateTo({
            url: `/pages/address/self`,
            events: {
                selfInfo: function (data) {
                    that.setData({ 'form.self_id': data.self_id })
                    that.setData({ 'form.self_name': data.self_name })
                    that.setData({ 'form.longitude': data.longitude })
                    that.setData({ 'form.latitude': data.latitude })
                    that.setData({ 'form.address': data.address })
                }
            },
        })
    },
    // 确认提交
    onSubmit: async function (e) {
        const that = this;
        const params = e.detail.value;
        const id = that.data.id;
        if (!this.WxValidate.checkForm(params)) {
            const error = this.WxValidate.errorList[0];
            wx.showToast({ title: `${error.msg}`, icon: 'error', duration: 2000 })
            return false
        } else {
            if (params.self_id) {
                let arr;
                if (id) arr = await app.$post(`/groupBuy/api/addresses/${id}`, params);
                else arr = await app.$post(`/groupBuy/api/addresses`, params);
                if (arr.errcode == '0') { wx.showToast({ title: `维护地址完成`, icon: 'success', duration: 2000 }); that.back(); }
                else wx.showToast({ title: `${arr.errmsg}`, icon: 'error', duration: 2000 })
            } else wx.showToast({ title: `请选择自提点`, icon: 'error', duration: 2000 })
        }
    },
    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        const that = this;
        that.setData({ id: options.id || '' });
        // 计算高度
        that.searchHeight()
        //验证规则函数
        that.initValidate();
        // 监听用户是否登录
        that.watchLogin();
    },
    // 监听用户是否登录
    watchLogin: async function () {
        const that = this;
        wx.getStorage({
            key: 'token',
            success: async res => {
                let id = that.data.id;
                if (id) {
                    const arr = await app.$get(`/groupBuy/api/addresses/${id}`);
                    if (arr.errcode == '0') {
                        const aee = await app.$get(`/groupBuy/api/self/${arr.data.self_id}`);
                        if (aee.errcode == '0') {
                            arr.data.self_name = aee.data.name;
                            that.setData({ form: arr.data })
                        }
                    }
                } else {
                    that.setData({ form: { user_id: res.data._id, openid: res.data.openid } })
                }
            },
            fail: res => {
                wx.redirectTo({ url: '/pages/index/index', })
            }
        })
    },
    // 计算高度
    searchHeight: function () {
        let frameStyle = this.data.frameStyle;
        let client = app.globalData.client;
        // 减去状态栏
        let infoHeight = client.windowHeight - (client.statusBarHeight + client.getMenu.height + (client.getMenu.top - client.statusBarHeight) * 2);
        // 是否减去底部菜单
        if (frameStyle.useBar) infoHeight = infoHeight - 50;
        if (infoHeight) this.setData({ infoHeight: infoHeight })
    },

    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady: function () {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow: function () {

    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide: function () {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload: function () {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh: function () {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom: function () {

    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage: function () {

    }
})