// pages/test/index.js
const app = getApp()
Page({

    /**
     * 页面的初始数据
     */
    data: {
        frameStyle: { useTop: true, name: '收货地址', leftArrow: true, useBar: false },
        // 主体高度
        infoHeight: '',
        list: [],
    },
    // 跳转菜单
    tabPath(e) {
        let { route } = e.detail.detail;
        if (route) wx.redirectTo({ url: `/${route}` })
    },
    back: function () {
        wx.navigateBack({ delta: 1 })
    },
    // 修改
    toEdit: function (e) {
        const { item } = e.currentTarget.dataset;
        wx.navigateTo({ url: `/pages/address/detail?id=${item._id}` })
    },
    // 删除
    toDel: function (e) {
        const that = this;
        const { item } = e.currentTarget.dataset;
        wx.showModal({
            title: '提示',
            content: '确定要删除该地址吗?',
            async success(res) {
                if (res.confirm) {
                    const arr = await app.$delete(`/groupBuy/api/addresses/${item._id}`);
                    if (arr.errcode == '0') {
                        wx.showToast({ title: `删除地址成功`, icon: 'success', duration: 2000 })
                        that.watchLogin()
                    } else {
                        wx.showToast({ title: `${arr.errmsg}`, icon: 'error', duration: 2000 })
                    }
                }
            }
        })
    },
    // 确定默认地址
    toEnable: async function (e) {
        const that = this;
        const { item } = e.currentTarget.dataset;
        const arr = await app.$post(`/groupBuy/api/addresses/default/${item._id}`, { user_id: item.user_id });
        if (arr.errcode == '0') { wx.showToast({ title: `设置默认成功`, icon: 'success', duration: 2000 }); that.watchLogin(); }
        else wx.showToast({ title: `${arr.errmsg}`, icon: 'error', duration: 2000 })
    },
    // 添加收货地址
    toAdd: function () {
        wx.navigateTo({ url: '/pages/address/detail' })
    },
    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        const that = this;
        // 监听用户是否登录
        that.watchLogin();
        // 计算高度
        that.searchHeight()
    },
    // 监听用户是否登录
    watchLogin: async function () {
        const that = this;
        wx.getStorage({
            key: 'token',
            success: async res => {
                let user_id = res.data._id;
                const aee = await app.$get(`/groupBuy/api/self`, { status: '0' });
                if (aee.errcode == '0') {
                    const arr = await app.$get(`/groupBuy/api/addresses`, { user_id: user_id });
                    if (arr.errcode == '0') {
                        for (const val of arr.data) {
                            let data = aee.data.find((i) => i._id == val.self_id);
                            if (data) val.self_name = data.name;
                        }
                        that.setData({ list: arr.data })
                    }
                }
            },
            fail: res => {
                wx.redirectTo({ url: '/pages/index/index', })
            }
        })
    },
    // 计算高度
    searchHeight: function () {
        let frameStyle = this.data.frameStyle;
        let client = app.globalData.client;
        // 减去状态栏
        let infoHeight = client.windowHeight - (client.statusBarHeight + client.getMenu.height + (client.getMenu.top - client.statusBarHeight) * 2);
        // 是否减去底部菜单
        if (frameStyle.useBar) infoHeight = infoHeight - 50;
        if (infoHeight) this.setData({ infoHeight: infoHeight })
    },

    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady: function () {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow: function () {
        const that = this;
        that.watchLogin();
    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide: function () {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload: function () {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh: function () {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom: function () {

    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage: function () {

    }
})