// pages/login/login.js
const chooseLocation = requirePlugin('chooseLocation');
var QQMapWX = require('../../utils/qqmap-wx-jssdk');
var qqmapsdk;
const app = getApp()
Page({

    /**
     * 页面的初始数据
     */
    data: {
        frameStyle: { useTop: true, name: '选择自提点', leftArrow: true, useBar: false },
        // 主体高度
        infoHeight: '',
        address_url: '/image/location1.png',
        // 当前位置
        address: '',
        list: [],
        // 距离
        elements: [],
        //列表经纬度
        tolist: [],
    },
    back: function (item) {
        const that = this;
        let obj = {
            self_id: item._id,
            self_name: item.name,
            latitude: parseFloat(item.latitude),
            longitude: parseFloat(item.longitude),
            address: that.data.address.address
        }
        wx.navigateBack({ url: `/pages/address/detail` })
        const eventChannel = this.getOpenerEventChannel()
        eventChannel.emit('selfInfo', obj);
    },
    // 选择自提点
    toChange: function (e) {
        const that = this;
        const { item } = e.currentTarget.dataset;
        that.back(item);
    },
    // 重新定位
    toLocation: function () {
        let mapInfo = app.globalData.mapInfo;
        wx.navigateTo({ url: `plugin://chooseLocation/index?key=${mapInfo.key}&referer=${mapInfo.referer}` });
    },
    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        const that = this;
        // 计算高度
        that.searchHeight();
        // 监听用户登录
        that.watchLogin();
        // 查询当前位置信息
        that.searchLocation();
    },
    // 监听用户是否登录
    watchLogin: function () {
        wx.showLoading({ title: '加载中' })
        const that = this;
        // 查询自提点信息，并计算距离
        wx.getStorage({
            key: 'token',
            success: async res => {
                const arr = await app.$get(`/groupBuy/api/self`, { status: '0' });
                if (arr.errcode == '0') {
                    wx.getLocation({
                        type: 'wgs84',
                        success(local) {
                            let from = { latitude: local.latitude, longitude: local.longitude };
                            that.searchElements(from, arr.data)
                            wx.hideLoading()
                        }
                    })
                }
            },
            fail: res => {
                wx.redirectTo({ url: '/pages/index/index', })
            }
        })
    },
    // 计算两点地理坐标距离
    searchElements: function (from, to) {
        const that = this;
        qqmapsdk.calculateDistance({
            from, to,
            success: function (res) {
                let distanceList = res.result.elements;
                for (const p1 of to) {
                    let distanceInfo = distanceList.find((i) => i.to.lat == parseFloat(p1.latitude) && i.to.lng == parseFloat(p1.longitude));
                    if (distanceInfo) p1.distance = distanceInfo.distance;
                }
                that.setData({ list: to })
            },
            fail: function (error) {
                wx.showToast({ title: `${error.message}`, icon: 'error', duration: 2000 })
            },
        });
    },
    // 获取当前位置
    searchLocation: async function () {
        const that = this;
        qqmapsdk = new QQMapWX({ key: `${app.globalData.mapInfo.key}` });
        qqmapsdk.reverseGeocoder({
            success(res) {
                if (res.status == '0') { that.setData({ address: res.result }) }
                else { wx.showToast({ title: `${res.message}`, duration: 2000, icon: 'error' }) }
            }
        })
    },
    // 计算高度
    searchHeight: function () {
        const that = this;
        let frameStyle = this.data.frameStyle;
        let client = app.globalData.client;
        let infoHeight = client.windowHeight;
        // 是否去掉状态栏
        if (frameStyle.useTop) infoHeight = infoHeight - (client.statusBarHeight + client.getMenu.height + (client.getMenu.top - client.statusBarHeight) * 2);
        // 是否减去底部菜单
        if (frameStyle.useBar) infoHeight = infoHeight - 50;
        if (infoHeight) that.setData({ infoHeight: infoHeight })
    },
    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady: function () {
    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow: async function () {
        const that = this;
        const location = chooseLocation.getLocation();
        if (location) {
            that.setData({ address: location })
            const arr = await app.$get(`/groupBuy/api/self`, { status: '0' });
            if (arr.errcode == '0') {
                let from = { latitude: location.latitude, longitude: location.longitude }
                that.searchElements(from, arr.data)
            }
        }
    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide: function () {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload: function () {
        chooseLocation.setLocation(null);
    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh: function () {
    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom: function () {
    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage: function () {

    }
})