// pages/test/index.js
const app = getApp()

Page({

    /**
     * 页面的初始数据
     */
    data: {
        frameStyle: { useTop: true, name: '购物车', leftArrow: false, useBar: true },
        // 主体高度
        infoHeight: '',
        fileUrl: app.globalData.fileUrl,
        src: '/image/logo.png',
        // 是否全选
        isAll: true,
        // 商品列表
        list: [],
        // 商品列表类别数
        market_num: 0,
        // 商品总额
        totalMoney: 0,
    },
    // 跳转菜单
    tabPath(e) {
        let { route } = e.detail.detail;
        if (route) wx.redirectTo({ url: `/${route}` })
    },
    back: function () {
        wx.navigateBack({ url: '/pages/home/index' })
    },
    //全选
    selectAll: function (e) {
        const that = this;
        const list = that.data.list;
        const isAll = that.data.isAll;
        let data = [];
        for (const val of list) { if (isAll) { val.check = false; data.push(val) } else { val.check = true; data.push(val) } }
        that.setData({ list: data });
        // 计算长度
        that.countLength();
        // 计算总额
        that.countMoney();
        // 赋值是否全选
        that.setData({ isAll: isAll ? false : true })
    },
    //删除订单
    onClose: function (e) {
        const that = this;
        const list = that.data.list;
        const { id } = e.target.dataset;
        let data = list.filter((i) => i._id != id);
        wx.setStorage({ key: "order_maket", data: data })
        that.setData({ list: data });
        // 计算长度
        that.countLength();
        // 计算总额
        that.countMoney();
    },
    // 选择商品
    marketChange: function (e) {
        const that = this;
        const list = that.data.list;
        const { value } = e.detail;
        let data = [];
        for (const p1 of list) {
            let p2 = value.find((i) => i == p1._id);
            if (p2) p1.check = true;
            else p1.check = false;
            data.push(p1);
        }
        that.setData({ list: data });
        // 计算长度
        that.countLength();
        // 计算总额
        that.countMoney();
    },
    // 增加
    onePlus: function (e) {
        const that = this;
        const list = that.data.list;
        let value = e.currentTarget.dataset.item;
        let data = [];
        for (const val of list) { if (val._id == value._id) { val.buy_num = val.buy_num + 1 } data.push(val) }
        that.setData({ list: data });
        wx.setStorage({ key: "order_maket", data: data })
        // 计算长度
        that.countLength();
        // 计算总额
        that.countMoney();
    },
    // 减少
    oneMinus: function (e) {
        const that = this;
        const list = that.data.list;
        let value = e.currentTarget.dataset.item;
        let data = [];
        for (const val of list) {
            if (val._id == value._id) { val.buy_num = Number(val.buy_num) - 1; }
            if (val && val.buy_num != 0) { data.push(val) }
        }
        wx.setStorage({ key: "order_maket", data: data })
        that.setData({ list: data });
        // 计算长度
        that.countLength();
        // 计算总额
        that.countMoney();
    },
    // 计算长度
    countLength: function () {
        const that = this;
        const list = that.data.list;
        let length = 0;
        for (const val of list) { if (val.check) length += 1 }
        that.setData({ market_num: length })
    },
    // 计算总额
    countMoney: function () {
        const that = this;
        const list = that.data.list;
        let totalMoney = 0;
        for (const val of list) { if (val.check) { let total = Number(val.price) * Number(val.buy_num); totalMoney += Number(total); } }
        that.setData({ totalMoney: totalMoney.toFixed(2) })
    },
    // 去结算
    toSettle: function () {
        const that = this;
        const list = that.data.list;
        wx.setStorage({ key: "order_maket", data: list })
        wx.navigateTo({ url: '/pages/market_settle/index' })
    },
    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        const that = this;
        // 计算高度
        that.searchHeight();
        // 监听用户是否登录
        that.watchLogin();
    },
    // 监听用户是否登录
    watchLogin: function () {
        const that = this;
        wx.getStorage({
            key: 'token',
            success: async res => {
                wx.getStorage({
                    key: 'order_maket',
                    success: async arr => {
                        for (const val of arr.data) { val.check = true };
                        // 赋值列表
                        that.setData({ list: arr.data });
                        // 计算长度
                        that.countLength();
                        // 计算总额
                        that.countMoney();
                    },
                })
            },
            fail: res => {
                wx.redirectTo({ url: '/pages/index/index', })
            }
        })
    },
    // 计算高度
    searchHeight: function () {
        let frameStyle = this.data.frameStyle;
        let client = app.globalData.client;
        let infoHeight = client.windowHeight;
        // 是否去掉状态栏
        if (frameStyle.useTop) infoHeight = infoHeight - (client.statusBarHeight + client.getMenu.height + (client.getMenu.top - client.statusBarHeight) * 2);
        // 是否减去底部菜单
        if (frameStyle.useBar) infoHeight = infoHeight - 50;
        if (infoHeight) this.setData({ infoHeight: infoHeight })
    },

    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady: function () {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow: function () {

    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide: function () {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload: function () {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh: function () {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom: function () {

    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage: function () {

    }
})