const moment = require("../../utils/moment.min")
import WxValidate from '../../utils/wxValidate'
const app = getApp()
Page({

    /**
     * 页面的初始数据
     */
    data: {
        frameStyle: { useTop: true, name: '确认订单', leftArrow: true, useBar: false },
        // 主体高度
        infoHeight: '',
        fileUrl: app.globalData.fileUrl,
        src: '/image/logo.png',
        tel_url: '/image/tel.png',
        form: {},
        // 弹框
        dialog: { title: '支付订单', show: false, type: '1' },
        // 未支付的订单信息
        orderForm: {}
    },
    initValidate() {
        const rules = { receive: { required: true }, receive_phone: { required: true, tel: true } }
        // 验证字段的提示信息，若不传则调用默认的信息
        const messages = { receive: { required: '收货人姓名', }, receive_phone: { required: '联系电话', } };
        this.WxValidate = new WxValidate(rules, messages)
    },
    // 跳转菜单
    tabPath(e) {
        let { route } = e.detail.detail;
        if (route) wx.redirectTo({ url: `/${route}` })
    },
    back: function () {
        wx.navigateBack({ url: '/pages/home/index' })
    },
    // 拨打电话
    toTel: function (e) {
        const { tel } = e.currentTarget.dataset;
        wx.makePhoneCall({ phoneNumber: tel })
    },
    onSubmit: async function (e) {
        const that = this;
        const params = e.detail.value;
        const data = that.data.form;
        if (!this.WxValidate.checkForm(params)) {
            const error = this.WxValidate.errorList[0];
            wx.showToast({ title: `${error.msg}`, icon: 'error', duration: 2000 })
            return false
        } else {
            params._tenant = 'test1';
            params.user_id = data.user_id;
            params.openid = data.openid;
            params.market = data.market;
            params.market_num = data.market_num;
            params.agent = data.agent;
            params.agent_phone = data.agent_phone;
            params.price = data.price;
            params.buy_time = moment().format('YYYY-MM-DD HH:mm:ss');
            const arr = await app.$post(`/groupBuy/api/order`, params);
            if (arr.errcode == '0') {
                that.setData({ orderForm: arr.data })
                wx.showToast({ title: `提交订单成功`, icon: 'success', duration: 2000 })
                that.setData({ dialog: { title: '支付订单', show: true, type: '1' } })
            } else {
                wx.showToast({ title: `${arr.errmsg}`, icon: 'error', duration: 2000 })
            }
        }
    },
    // 关闭弹框
    toClose: function () {
        const that = this;
        that.setData({ dialog: { title: '支付订单', show: false, type: '1' } })
    },
    // 支付
    toPayment: async function () {
        const that = this;
        const params = that.data.orderForm;
        let obj = { config: 'groupBuyApp', money: params.price, openid: params.openid, order_no: params.num }
        const arr = await app.$post(`/wechat/api/pay/payOrder`, obj)
        if (arr.errcode == '0') {
            wx.requestPayment({
                "timeStamp": arr.data.timestamp,
                "nonceStr": arr.data.nonceStr,
                "package": `prepay_id=${arr.data.prepay_id}`,
                "signType": arr.data.signType,
                "paySign": arr.data.paySign,
                "success": async function (res) {
                    wx.showToast({ title: `支付成功`, icon: 'success', duration: 2000 });
                    const aee = await app.$post(`/groupBuy/api/order/${params._id}`, { status: '1' });
                    if (aee.errcode == '0') {
                        wx.removeStorage({ key: 'order_maket', success(res) { wx.redirectTo({ url: `/pages/my/index` }) } })
                    }
                },
                "fail": function (res) {
                    wx.showToast({ title: `支付未成功`, icon: 'error', duration: 2000 })
                    wx.removeStorage({ key: 'order_maket', success(res) { wx.redirectTo({ url: `/pages/my/index` }) } })
                },
            })
        }
    },
    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        const that = this;
        // 计算高度
        that.searchHeight()
        //验证规则函数
        that.initValidate();
        // 监听用户是否登录
        that.watchLogin();
    },
    // 监听用户是否登录
    watchLogin: function () {
        const that = this;
        wx.getStorage({
            key: 'token',
            success: async res => {
                wx.getStorage({
                    key: 'order_maket',
                    success: async arr => {
                        // 订单信息
                        let data = { user_id: res.data._id, openid: res.data.openid, market: arr.data, market_num: arr.data.length };
                        // 收货人信息
                        const aee = await app.$get(`/groupBuy/api/addresses`, { user_id: data.user_id, is_default: true });
                        if (aee.errcode == '0' && aee.total > 0) {
                            let address = aee.data[0];
                            data.receive = address.user_name;
                            data.receive_phone = address.phone;
                            // 自提点信息
                            const att = await app.$get(`/groupBuy/api/self/${address.self_id}`);
                            if (att.errcode == '0') {
                                data.self_id = att.data._id;
                                data.self_name = att.data.name;
                                data.address = att.data.province + att.data.city + att.data.area + att.data.address;
                                data.agent = att.data.contacts;
                                data.agent_phone = att.data.contact;
                            }
                        } else {
                            wx.showToast({ title: `暂无收货地址`, icon: 'success', duration: 2000 })
                        }
                        // 计算订单价格
                        let price = 0;
                        for (const val of data.market) {
                            let money = Number(val.buy_num) * Number(val.price);
                            price += money;
                        }
                        data.price = price.toFixed(2);
                        that.setData({ form: data })
                    },
                })
            },
            fail: res => {
                wx.redirectTo({ url: '/pages/index/index', })
            }
        })
    },
    // 计算高度
    searchHeight: function () {
        let frameStyle = this.data.frameStyle;
        let client = app.globalData.client;
        let infoHeight = client.windowHeight;
        // 是否去掉状态栏
        if (frameStyle.useTop) infoHeight = infoHeight - (client.statusBarHeight + client.getMenu.height + (client.getMenu.top - client.statusBarHeight) * 2);
        // 是否减去底部菜单
        if (frameStyle.useBar) infoHeight = infoHeight - 50;
        if (infoHeight) this.setData({ infoHeight: infoHeight })
    },

    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady: function () {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow: function () {

    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide: function () {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload: function () {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh: function () {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom: function () {

    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage: function () {

    }
})