// pages/test/index.js
const app = getApp();
import {
    my_order,
    my_dispatch
} from '../../utils/dict';
Page({
    /**
     * 页面的初始数据
     */
    data: {
        frameStyle: {
            useTop: true,
            name: '我的',
            leftArrow: false,
            useBar: true
        },
        // 主体高度
        infoHeight: '',
        // one背景
        my_bg: '/image/img-background.png',
        // 用户信息
        user: {},
        avatarUrl: 'https://thirdwx.qlogo.cn/mmopen/vi_32/POgEwh4mIHO4nibH0KlMECNjjGxQUq24ZEaGT4poC6icRiccVGKSyXwibcPq4BWmiaIGuG1icwxaQX6grC9VemZoJ8rg/132',
        // 我的订单
        orderList: my_order,
        // 是否有自提点
        selectAddrStatus: false,
        addressInfo: {},
        tel_url: '/image/tel.png',
        // 我的派单
        dispatchList: my_dispatch
    },
    // 扫码登陆
    toScan() {
        wx.scanCode({
            onlyFromCamera: true,
            scanType: 'qrCode',
            success: (result, scanType) => {
                let obj = result.result;
                if (!obj) {
                    wx.showToast({
                        title: '数据错误',
                    })
                    return
                }
                let params = JSON.parse(obj)
                const { path } = params
                if (path === 'scan') {
                    wx.navigateTo({
                        url: `/pages/web_login/index?params=${obj}`,
                    })
                } else if (path === 'bind') {
                    wx.navigateTo({
                        url: `/pages/web_bind/index?params=${obj}`,
                    })
                }

            },
            fail: (e) => {
                console.log('in error')
                console.log(e)
            }
        })
    },

    // 跳转菜单
    tabPath(e) {
        let {
            route
        } = e.detail.detail;
        if (route) wx.redirectTo({
            url: `/${route}`
        })
    },
    back: function () {
        wx.navigateBack({
            url: '/pages/home/index'
        })
    },
    // 我的订单
    toOrrder: function (e) {
        const {
            item
        } = e.currentTarget.dataset;
        wx.navigateTo({
            url: `/pages/my_order/index?type=${item.type}`
        })
    },
    // 切换自提点
    toSelf: function (e) {
        wx.navigateTo({
            url: `/pages/address/index`
        })
    },
    // 拨打电话
    toTel: function (e) {
        const {
            tel
        } = e.currentTarget.dataset;
        wx.makePhoneCall({
            phoneNumber: tel
        })
    },
    // 我的派单
    toDispatch: function (e) {
        const {
            item
        } = e.currentTarget.dataset;
        wx.navigateTo({
            url: `/pages/my_dispatch/index?type=${item.type}`
        })
    },
    // 去购物
    toBuy: function () {
        wx.redirectTo({
            url: '/pages/home/index'
        })
    },
    // 获取头像
    async onChooseAvatar(e) {
        const that = this;
        let user = that.data.user;
        const {
            avatarUrl
        } = e.detail;
        const arr = await app.$post(`/groupBuy/api/user/${user.id}`, {
            icon: avatarUrl
        });
        if (arr.errcode == '0') {
            that.watchLogin()
        } else {
            wx.showToast({
                title: `${arr.errmsg}`,
                icon: 'error',
                duration: 2000
            })
        }
    },
    // 获取昵称
    toNick: async function (e) {
        const that = this;
        const {
            value
        } = e.detail;
        let user = that.data.user;
        const arr = await app.$post(`/groupBuy/api/user/${user.id}`, {
            name: value
        });
        if (arr.errcode == '0') {
            that.watchLogin()
        } else {
            wx.showToast({
                title: `${arr.errmsg}`,
                icon: 'error',
                duration: 2000
            })
        }
    },
    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        const that = this;
        // 计算高度
        that.searchHeight();
        // 监听用户登陆
        that.watchLogin();
    },
    watchLogin: async function () {
        const that = this;
        wx.getStorage({
            key: 'token',
            success: async res => {
                const aee = await app.$get(`/groupBuy/api/user/${res.data.id}`);
                if (aee.errcode == '0') {
                    app.globalData.userInfo = aee.data;
                    wx.setStorage({
                        key: "token",
                        data: aee.data
                    })
                    that.setData({
                        user: aee.data
                    });
                }
                const arr = await app.$get(`/groupBuy/api/addresses`, {
                    user_id: res.data._id,
                    is_default: true
                });
                if (arr.errcode == '0') {
                    if (arr.total > 0) {
                        that.setData({
                            selectAddrStatus: true
                        });
                        const aee = await app.$get(`/groupBuy/api/self/${arr.data[0].self_id}`);
                        if (aee.errcode == '0') {
                            that.setData({
                                addressInfo: aee.data
                            })
                        }
                    }
                }
            },
            fail: async res => {
                wx.redirectTo({
                    url: '/pages/index/index',
                })
            }
        })
    },
    // 计算高度
    searchHeight: function () {
        let frameStyle = this.data.frameStyle;
        let client = app.globalData.client;
        let infoHeight = client.windowHeight;
        // 是否去掉状态栏
        if (frameStyle.useTop) infoHeight = infoHeight - (client.statusBarHeight + client.getMenu.height + (client.getMenu.top - client.statusBarHeight) * 2);
        // 是否减去底部菜单
        if (frameStyle.useBar) infoHeight = infoHeight - 50;
        if (infoHeight) this.setData({
            infoHeight: infoHeight
        })
    },

    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady: function () {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow: function () {

    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide: function () {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload: function () {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh: function () {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom: function () {

    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage: function () {

    }
})