// pages/login/login.js
const moment = require("../../utils/moment.min")
import { status } from '../../utils/dict';
const app = getApp()
Page({

    /**
     * 页面的初始数据
     */
    data: {
        frameStyle: { useTop: true, name: '我的订单', leftArrow: true, useBar: false },
        // 主体高度
        infoHeight: '',
        tabs: {
            active: 'a',
            list: [
                { title: '待支付', name: 'a' },
                { title: '已支付', name: 'b' },
                { title: '订单确认', name: 'c' },
                { title: '配货中', name: 'd' },
                { title: '待提货', name: 'e' },
                { title: '已提货', name: 'f' },
                { title: '订单完成', name: 'g' },
                { title: '订单取消', name: 'h' },
            ],
        },
        list: [],
        statusList: status,
        dialog: { title: '详细信息', show: false, type: '1' },
        info: {},
        selfInfo: {},
        fileUrl: app.globalData.fileUrl,
        src: '/image/logo.png',
    },
    back: function () {
        wx.navigateBack({ url: '/pages/my/index' })
    },
    // 选项卡
    tabsChange: function (e) {
        const that = this;
        that.setData({ 'tabs.active': e.detail.name });
        that.watchLogin();
    },
    // 查看
    toView: async function (e) {
        const that = this;
        const { item } = e.currentTarget.dataset;
        const arr = await app.$get(`/groupBuy/api/order/${item._id}`);
        if (arr.errcode == '0') {
            const aee = await app.$get(`/groupBuy/api/self/${arr.data.self_id}`);
            if (aee.errcode == '0') {
                arr.data.self_name = aee.data.name;
                that.setData({ info: arr.data })
            }
            that.setData({ dialog: { title: '详细信息', show: true, type: '1' } })
        }
    },
    // 提货信息
    toTake: async function (e) {
        const that = this;
        const { item } = e.currentTarget.dataset;
        const arr = await app.$get(`/groupBuy/api/self/${item.self_id}`);
        if (arr.errcode == '0') {
            that.setData({ selfInfo: arr.data })
            that.setData({ dialog: { title: '提货信息', show: true, type: '2' } })
        }
    },
    // 关闭弹框
    toClose: function () {
        const that = this;
        that.setData({ dialog: { title: '详细信息', show: false, type: '1' } })
    },
    // 支付
    toSettle: async function (e) {
        const that = this;
        const { item } = e.currentTarget.dataset;
        let obj = { config: 'groupBuyApp', money: Number(item.price), openid: item.openid, order_no: item.num }
        const arr = await app.$post(`/wechat/api/pay/payOrder`, obj)
        if (arr.errcode == '0') {
            wx.requestPayment({
                "timeStamp": arr.data.timestamp,
                "nonceStr": arr.data.nonceStr,
                "package": `prepay_id=${arr.data.prepay_id}`,
                "signType": arr.data.signType,
                "paySign": arr.data.paySign,
                "success": async function (res) {
                    wx.showToast({ title: `支付成功`, icon: 'success', duration: 2000 });
                    const aee = await app.$post(`/groupBuy/api/order/${item._id}`, { status: '1' });
                    if (aee.errcode == '0') { that.watchLogin() }
                },
                "fail": function (res) {
                    wx.showToast({ title: `支付未成功`, icon: 'error', duration: 2000 })
                    that.watchLogin()
                },
            })
        }
    },
    // 订单取消
    toCancel: async function (e) {
        const that = this;
        const { item } = e.currentTarget.dataset;
        wx.showModal({
            title: '温馨提示',
            content: '您确认要取消订单吗？',
            success: async (res) => {
                if (res.confirm == true) {
                    const arr = await app.$post(`/groupBuy/api/order/${item._id}`, { status: '7' });
                    if (arr.errcode == '0') {
                        wx.showToast({ title: `订单取消成功`, icon: 'success', duration: 2000 })
                        that.watchLogin()
                    } else {
                        wx.showToast({ title: `${arr.errmsg}`, icon: 'error', duration: 2000 })
                    }
                }
            },
        })
    },
    // 提货提交
    onTake: function (e) {
        const that = this;
        const { item } = e.currentTarget.dataset;
        wx.showModal({
            title: '温馨提示',
            content: '您确认已经提取货物了吗？',
            success: async (res) => {
                if (res.confirm == true) {
                    const arr = await app.$post(`/groupBuy/api/order/${item._id}`, { status: '5', sign_time: moment().format('YYYY-MM-DD HH:mm:ss') });
                    if (arr.errcode == '0') {
                        wx.showToast({ title: `货物提取成功`, icon: 'success', duration: 2000 })
                        that.watchLogin()
                    } else {
                        wx.showToast({ title: `${arr.errmsg}`, icon: 'error', duration: 2000 })
                    }
                }
            },
        })
    },

    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        const that = this;
        that.setData({ 'tabs.active': options.type || 'a' })
        // 计算高度
        that.searchHeight();
        // 监听用户是否登录
        that.watchLogin();
    },
    // 监听用户是否登录
    watchLogin: function () {
        const that = this;
        const tabs = that.data.tabs;
        wx.getStorage({
            key: 'token',
            success: async res => {
                let info = { user_id: res.data._id };
                if (tabs.active == 'a') info.status = '0';
                else if (tabs.active == 'b') info.status = '1';
                else if (tabs.active == 'c') info.status = '2';
                else if (tabs.active == 'd') info.status = '3';
                else if (tabs.active == 'e') info.status = '4';
                else if (tabs.active == 'f') info.status = '5';
                else if (tabs.active == 'g') info.status = '6';
                else if (tabs.active == 'h') info.status = '7';
                const arr = await app.$get(`/groupBuy/api/order`, info);
                if (arr.errcode == '0') {
                    for (const val of arr.data) { val.status_name = that.data.statusList.find((i) => i.value == val.status).label; }
                    that.setData({ list: arr.data })
                }
            },
            fail: res => {
                wx.redirectTo({ url: '/pages/index/index', })
            }
        })
    },
    // 计算高度
    searchHeight: function () {
        let frameStyle = this.data.frameStyle;
        let client = app.globalData.client;
        let infoHeight = client.windowHeight;
        // 是否去掉状态栏
        if (frameStyle.useTop) infoHeight = infoHeight - (client.statusBarHeight + client.getMenu.height + (client.getMenu.top - client.statusBarHeight) * 2);
        // 是否减去底部菜单
        if (frameStyle.useBar) infoHeight = infoHeight - 50;
        if (infoHeight) this.setData({ infoHeight: infoHeight })
    },

    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady: function () {
    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow: function () {

    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide: function () {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload: function () {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh: function () {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom: function () {
    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage: function () {

    }
})
